# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "access_key": "accessKey",
    "api_version": "apiVersion",
    "authorized_keys": "authorizedKeys",
    "authorized_users": "authorizedUsers",
    "axfr_ips": "axfrIps",
    "backup_id": "backupId",
    "backups_enabled": "backupsEnabled",
    "boot_config_label": "bootConfigLabel",
    "check_attempts": "checkAttempts",
    "check_body": "checkBody",
    "check_interval": "checkInterval",
    "check_passive": "checkPassive",
    "check_path": "checkPath",
    "check_timeout": "checkTimeout",
    "cipher_suite": "cipherSuite",
    "client_conn_throttle": "clientConnThrottle",
    "config_id": "configId",
    "created_by": "createdBy",
    "deployments_active": "deploymentsActive",
    "deployments_total": "deploymentsTotal",
    "disk_id": "diskId",
    "domain_id": "domainId",
    "expire_sec": "expireSec",
    "filesystem_path": "filesystemPath",
    "in_": "in",
    "ip_address": "ipAddress",
    "is_public": "isPublic",
    "linode_id": "linodeId",
    "master_ips": "masterIps",
    "node_status": "nodeStatus",
    "nodebalancer_id": "nodebalancerId",
    "private_ip": "privateIp",
    "private_ip_address": "privateIpAddress",
    "record_type": "recordType",
    "refresh_sec": "refreshSec",
    "retry_sec": "retrySec",
    "rev_note": "revNote",
    "root_pass": "rootPass",
    "secret_key": "secretKey",
    "soa_email": "soaEmail",
    "ssh_key": "sshKey",
    "ssl_cert": "sslCert",
    "ssl_commonname": "sslCommonname",
    "ssl_fingerprint": "sslFingerprint",
    "ssl_key": "sslKey",
    "stackscript_data": "stackscriptData",
    "stackscript_id": "stackscriptId",
    "status_down": "statusDown",
    "status_up": "statusUp",
    "swap_size": "swapSize",
    "ttl_sec": "ttlSec",
    "ua_prefix": "uaPrefix",
    "user_defined_fields": "userDefinedFields",
    "user_gravatar_id": "userGravatarId",
    "watchdog_enabled": "watchdogEnabled",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "accessKey": "access_key",
    "apiVersion": "api_version",
    "authorizedKeys": "authorized_keys",
    "authorizedUsers": "authorized_users",
    "axfrIps": "axfr_ips",
    "backupId": "backup_id",
    "backupsEnabled": "backups_enabled",
    "bootConfigLabel": "boot_config_label",
    "checkAttempts": "check_attempts",
    "checkBody": "check_body",
    "checkInterval": "check_interval",
    "checkPassive": "check_passive",
    "checkPath": "check_path",
    "checkTimeout": "check_timeout",
    "cipherSuite": "cipher_suite",
    "clientConnThrottle": "client_conn_throttle",
    "configId": "config_id",
    "createdBy": "created_by",
    "deploymentsActive": "deployments_active",
    "deploymentsTotal": "deployments_total",
    "diskId": "disk_id",
    "domainId": "domain_id",
    "expireSec": "expire_sec",
    "filesystemPath": "filesystem_path",
    "in": "in_",
    "ipAddress": "ip_address",
    "isPublic": "is_public",
    "linodeId": "linode_id",
    "masterIps": "master_ips",
    "nodeStatus": "node_status",
    "nodebalancerId": "nodebalancer_id",
    "privateIp": "private_ip",
    "privateIpAddress": "private_ip_address",
    "recordType": "record_type",
    "refreshSec": "refresh_sec",
    "retrySec": "retry_sec",
    "revNote": "rev_note",
    "rootPass": "root_pass",
    "secretKey": "secret_key",
    "soaEmail": "soa_email",
    "sshKey": "ssh_key",
    "sslCert": "ssl_cert",
    "sslCommonname": "ssl_commonname",
    "sslFingerprint": "ssl_fingerprint",
    "sslKey": "ssl_key",
    "stackscriptData": "stackscript_data",
    "stackscriptId": "stackscript_id",
    "statusDown": "status_down",
    "statusUp": "status_up",
    "swapSize": "swap_size",
    "ttlSec": "ttl_sec",
    "uaPrefix": "ua_prefix",
    "userDefinedFields": "user_defined_fields",
    "userGravatarId": "user_gravatar_id",
    "watchdogEnabled": "watchdog_enabled",
}
