# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetObjectStorageClusterResult:
    """
    A collection of values returned by getObjectStorageCluster.
    """
    def __init__(__self__, domain=None, id=None, region=None, static_site_domain=None, status=None):
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        __self__.domain = domain
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        __self__.region = region
        if static_site_domain and not isinstance(static_site_domain, str):
            raise TypeError("Expected argument 'static_site_domain' to be a str")
        __self__.static_site_domain = static_site_domain
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        __self__.status = status
class AwaitableGetObjectStorageClusterResult(GetObjectStorageClusterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetObjectStorageClusterResult(
            domain=self.domain,
            id=self.id,
            region=self.region,
            static_site_domain=self.static_site_domain,
            status=self.status)

def get_object_storage_cluster(domain=None,id=None,region=None,static_site_domain=None,status=None,opts=None):
    """
    Provides information about a Linode Object Storage Cluster


    ## Attributes

    The Linode Object Storage Cluster resource exports the following attributes:

    * `domain` - The base URL for this cluster.

    * `status` - This cluster's status.

    * `region` - The region this cluster is located in.

    * `static_site_domain` - The base URL for this cluster used when hosting static sites.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-linode/blob/master/website/docs/d/object_storage_cluster.html.md.


    :param str id: The unique ID of this cluster. 
    """
    __args__ = dict()


    __args__['domain'] = domain
    __args__['id'] = id
    __args__['region'] = region
    __args__['staticSiteDomain'] = static_site_domain
    __args__['status'] = status
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('linode:index/getObjectStorageCluster:getObjectStorageCluster', __args__, opts=opts).value

    return AwaitableGetObjectStorageClusterResult(
        domain=__ret__.get('domain'),
        id=__ret__.get('id'),
        region=__ret__.get('region'),
        static_site_domain=__ret__.get('staticSiteDomain'),
        status=__ret__.get('status'))
